from srai_core.tools_docker import build_docker
from srai_core.command_handler_subprocess import CommandHandlerSubprocess


def main():
    command_handler = CommandHandlerSubprocess()
    build_docker(command_handler)


if __name__ == "__main__":
    main()



import os
from typing import List
from srai_core.tools_docker import (
    get_client_ssh,
    build_docker,
    list_container_name,
    get_image_tag,
    start_container_ssh,
    stop_container,
    release_docker_aws,
    remove_container,
)
from srai_core.command_handler_ssh import CommandHandlerSsh


def main():
    hostname = "18.185.177.93"  # TODO these could even come from boto3
    username = "ubuntu"
    path_file_pem = "c:/key/lightsaildefaultkey-eu-central-1.pem"
    if not os.path.exists(path_file_pem):
        raise Exception(f"File {path_file_pem} does not exist")

    client_ssh = get_client_ssh(hostname, username, path_file_pem)
    command_handler = CommandHandlerSsh(client_ssh)

    image_tag = get_image_tag()
    container_name = image_tag.split(":")[0].split("/")[-1]

    list_container_name_present = list_container_name(client_ssh)
    if container_name in list_container_name_present:
        stop_container(command_handler, container_name)
        remove_container(command_handler, container_name)


if __name__ == "__main__":
    main()



from typing import Tuple

from paramiko import SSHClient

from srai_core.command_handler_base import CommandHandlerBase
from srai_core.tools_docker import get_client_ssh


class CommandHandlerSsh(CommandHandlerBase):
    def __init__(
        self,
        cliend_ssh: SSHClient,
    ) -> None:
        self.cliend_ssh = cliend_ssh

    def execute(
        self,
        command: str,
    ) -> Tuple[str, str]:
        # Execute the command
        print(command)
        _, stdout, stderr = self.cliend_ssh.exec_command(command)
        output_out = stdout.read().decode("utf-8").strip()
        print(output_out)
        output_err = stderr.read().decode("utf-8").strip()
        print(output_err)
        return output_out, output_err

    def to_dict(self) -> dict:
        raise NotImplementedError()

    @staticmethod
    def from_dict(dict_command_handler: dict) -> CommandHandlerBase:
        hostname = dict_command_handler["hostname"]
        username = dict_command_handler["username"]
        path_file_pem = dict_command_handler["path_file_pem"]

        client_ssh = get_client_ssh(hostname, username, path_file_pem)
        return CommandHandlerSsh(client_ssh)



import asyncio
import json
import sys

from srai_core.command_handler_base import CommandHandlerBase
from srai_core.tools_docker import (
    build_docker_async,
    get_image_tag,
    release_docker_local_to_aws_async,
    remove_container,
    start_container_async,
    stop_container,
)


async def srai_deploy():
    if len(sys.argv) < 2:
        print("Usage: deploy_docker deployment_file.json")
        sys.exit(1)

    path_deployment_file = sys.argv[1]
    with open(path_deployment_file) as f:
        deployment = json.load(f)
    for build_target in deployment["list_build_target"]:
        command_handler = CommandHandlerBase.from_dict(build_target)
        await build_docker_async(command_handler)

    for release_target in deployment["list_release_target"]:
        command_handler = CommandHandlerBase.from_dict(release_target)
        release_type = release_target["release_type"]
        if release_type == "release_docker_local_to_aws":
            await release_docker_local_to_aws_async(command_handler)
        else:
            print(f"Unknown release_type: {release_type}")
            sys.exit(1)

    for deploy_target in deployment["list_deploy_target"]:
        command_handler = CommandHandlerBase.from_dict(deploy_target)
        image_tag = get_image_tag()
        dict_env = deploy_target["environment_dict"]
        if "account_id" in deploy_target:
            account_id = deploy_target["account_id"]
        else:
            account_id = None
        if "region_name" in deploy_target:
            region_name = deploy_target["region_name"]
        else:
            region_name = None

        dict_env["IMAGE_TAG"] = image_tag

        container_name = image_tag.split(":")[0].split("/")[-1]
        stop_container(command_handler, container_name)
        remove_container(command_handler, container_name)
        await start_container_async(command_handler, account_id, region_name, image_tag, container_name, dict_env)


def main():
    asyncio.run(srai_deploy())


if __name__ == "__main__":
    main()



import os


class FileStoreDisk:
    def __init__(self, path_dir: str) -> None:
        self.path_dir = path_dir
        if not os.path.exists(self.path_dir):
            os.makedirs(self.path_dir)

    def get_path_file(self, key) -> str:
        return os.path.join(self.path_dir, key)

    def exists(self, key) -> bool:
        return os.path.isfile(self.get_path_file(key))

    def download(self, key) -> bool:
        pass

    def upload(self, key) -> bool:
        pass



from srai_core.tools_docker import build_docker
from srai_core.tools_docker import release_docker_aws
from srai_core.tools_docker import clone_repository, get_client_ssh, read_module_init
from srai_core.tools_env import get_string_from_env
from srai_core.command_handler_ssh import CommandHandlerSsh
import os


def main():
    hostname = get_string_from_env(
        "AWS_CNC_HOSTNAME"
    )  # TODO these could even come from boto3
    username = "ubuntu"
    path_file_pem = "c:/key/lightsaildefaultkey-eu-central-1.pem"
    if not os.path.exists(path_file_pem):
        raise Exception(f"File {path_file_pem} does not exist")

    ssh_client = get_client_ssh(hostname, username, path_file_pem)
    repository_name = read_module_init()["__title__"]
    command_handler = CommandHandlerSsh(ssh_client)
    git_token = get_string_from_env("GITHUB_TOKEN")
    path_target = f"~/{repository_name}"
    clone_repository(command_handler, repository_name, "~", git_token)  # TODO
    build_docker(command_handler, path_target)
    release_docker_aws(command_handler)


if __name__ == "__main__":
    main()



from setuptools import find_packages, setup

with open("README.md", "r") as f:
    long_description = f.read()

with open("requirements.txt", "r") as f:
    requirements = f.read().splitlines()


setup(
    name="srai-core",
    packages=find_packages(),
    version="0.10.3",  # TODO manual....
    license="MIT",
    package_data={},
    python_requires=">=3.5",
    install_requires=requirements,
    author="Jaap Oosterbroek",
    author_email="jaap.oosterbroek@southriverai.com",
    description="A library core functions used in other SRAI libraries.",
    entry_points={
        "console_scripts": [
            "srai_build=srai_core.script.srai_build:main",
            "srai_release=srai_core.script.srai_release:main",
            "srai_deploy=srai_core.script.srai_deploy:main",
            "build_docker=srai_core.script.build_docker:main",
            "deploy_docker=srai_core.script.deploy_docker:main",
            "deploy_docker_local=srai_core.script.deploy_docker_local:main",
            "deploy_docker_remote_ssh=srai_core.script.deploy_docker_remote_ssh:main",
            "stop_docker_remote=srai_core.script.stop_docker_remote:main",
            "release_docker_aws_local=srai_core.script.release_docker_aws_local:main",
            "release_docker_aws_ssh=srai_core.script.release_docker_aws_ssh:main",
            "release_code_public=srai_core.script.release_code_public:main",
            "create_repository=srai_core.script.create_repository:main",
            "list_images=srai_core.script.list_images:main",
            "list_containers_ssh = srai_core.script.list_containers_ssh:main",
            "list_container_status_ssh = srai_core.script.list_container_status_ssh:main",
            "list_commands=srai_core.script.list_commands:main",
            "docker_logs_ssh=srai_core.script.docker_logs_ssh:main",
        ],
    },
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/southriverai/srai-core",
    download_url="https://github.com/southriverai/srai-core/archive/v_01.tar.gz",
    keywords=["SRAI", "TOOLS"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",  # Define that your audience are developers
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",  # Again, pick a license
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
    ],
)



from abc import ABC, abstractmethod


class FileStore(ABC):
    def __init__(self, path_dir: str) -> None:
        self.path_dir = path_dir

    @abstractmethod
    def get_path_file(self, key) -> str:
        raise NotImplementedError()

    @abstractmethod
    def exists(self, key) -> bool:
        raise NotImplementedError()

    @abstractmethod
    def download(self, key) -> bool:
        raise NotImplementedError()

    @abstractmethod
    def upload(self, key) -> bool:
        raise NotImplementedError()
